.. inspyred documentation index

===========================================
inspyred: Bio-inspired Algorithms in Python
===========================================

.. toctree::
   :maxdepth: 4
   
   readme
   installation
   usage
   overview
   tutorial
   examples
   recipes
   reference
   troubleshooting
   contributing
   authorshistory   

=======
Indices
=======

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`